/*Sane defaults for themes that do not specify them, themes can override these */
/*This is loaded with GTK_STYLE_PROVIDER_PRIORITY_THEME so themes can override */

.caja-canvas-item {
    border-radius: 3px;
}

/* EelEditableLabel (icon labels) */
.caja-desktop.view .entry,
.caja-desktop.view .entry:focus,
.caja-desktop.view .entry:backdrop,
.caja-navigation-window .view .entry,
.caja-navigation-window .view .entry:active,
.caja-navigation-window .view .entry:focus,
.caja-navigation-window .view .entry:backdrop {
    border-image: none;
    border-style: solid;
    border-width: 1px;
    border-color: #000000;
    border-radius: 3px;
    color: #000000;
    text-shadow: none;
    background-image: -gtk-gradient(linear,
                                    left top, left bottom,
                                    from       (shade(rgba(255,255,255,1), 0.86)),
                                    color-stop (0.15, shade(rgba(255,255,255,1), 0.96)),
                                    color-stop (0.50, shade(rgba(255,255,255,1), 0.98)),
                                    to         (shade(rgba(255,255,255,1), 1.00)));
}

.caja-desktop.view .entry:selected,
.caja-desktop.view .entry:focus:selected,
.caja-desktop.view .entry:backdrop:selected,
.caja-navigation-window .view .entry:active,
.caja-navigation-window .view .entry:selected,
.caja-navigation-window .view .entry:focus:selected,
.caja-navigation-window .view .entry:backdrop:selected {
    background-color: @theme_selected_bg_color;
    color: @theme_selected_fg_color;
    text-shadow: none;
}


